# Plot Maker
`/publication/plotter/plotter.py` is a master script that generates the plots in the publication based on the results under the `/publication/results` directory. 

## Pre-requisites
- Python 3.11 or later
- `pip`, or a `virtualenv`

## Setup
```sh
cd /publication/plotter
pip install requirements.txt
```

## Run 
```sh
python plotter.py
```

Figures will be created under `/publication/plotter/figures`

